#!/bin/sh

export DUPLICACY_B2_ID=
export DUPLICACY_B2_KEY=
B2_BUCKET=test123-duplicacy

SNAPSHOT_ID=test1
#SNAPSHOT_ID=test2

set -eux

echo "==== PREPARE"

# prepare workspace
rm -rf /tmp/break-duplicacy
mkdir -p /tmp/break-duplicacy
cd /tmp/break-duplicacy

# prepare files
mkdir bak0 bak1 bak2
dd if=/dev/urandom of=bak0/fileA bs=1M count=10
dd if=/dev/urandom of=bak1/fileB bs=1M count=30   # should take ~30s to upload
dd if=/dev/urandom of=bak2/fileC bs=1M count=100  # should take ~90s to upload

# init
(cd bak0; duplicacy init test1 b2://$B2_BUCKET)
(cd bak1; duplicacy init test1 b2://$B2_BUCKET)
(cd bak2; duplicacy init $SNAPSHOT_ID b2://$B2_BUCKET)

# backup 0.1
(cd bak0; duplicacy backup)

# backup 0.2
echo asdf > bak0/asdf
mv -f bak0/fileA bak2/fileA
(cd bak0; duplicacy backup)

echo "==== RUN"

# now in parallel two backups and prune

# backup 1
cd bak1
duplicacy backup &
bak1pid=$!
cd -

# backup 2
sleep 1
cd bak2
duplicacy backup &
bak2pid=$!
cd -

# prune
sleep 5
(cd bak0; duplicacy prune -r 1)

# at this point prune should mark fileA as fossil and
# backup 1 should finish but backup 2 not yet
wait $bak1pid

# prune again
(cd bak0; duplicacy prune)

# at this point prune should delete fileA completely and
# backup 2 should finish
wait $bak2pid

# check backup is corrupted
cd bak2
duplicacy check -a || true
duplicacy cat fileA
